<?php

namespace FiloBlu\EsbRma\Model\Saver;

use FiloBlu\Esb\Api\Data\ObjectTypeDescriptorInterface;
use FiloBlu\Esb\Api\ObjectTypeSaverInterface;
use FiloBlu\Esb\Framework\ObjectType\Endpoint\AbstractEndpoint;
use Magento\Rma\Api\RmaRepositoryInterface;
use RuntimeException;

/**
 * Class RmaSaver
 * @package FiloBlu\Esb\Model\Saver
 */
class RmaSaver extends AbstractEndpoint implements ObjectTypeSaverInterface
{
    /**
     * @var RmaRepositoryInterface
     */
    private $rmaRepository;

    /**
     * RmaLoader constructor.
     * @param RmaRepositoryInterface $rmaRepository
     * @param ObjectTypeDescriptorInterface $objectTypeDescriptor
     */
    public function __construct(
        RmaRepositoryInterface $rmaRepository,
        ObjectTypeDescriptorInterface $objectTypeDescriptor
    ) {
        parent::__construct($objectTypeDescriptor);
        $this->rmaRepository = $rmaRepository;
    }


    /**
     * @inheritDoc
     */
    public function getName(): string
    {
        return 'Esb rma saver';
    }

    /**
     * @inheritDoc
     */
    public function getUniqueName(): string
    {
        return 'FiloBlu_Esb::rma_saver';
    }

    /**
     * @inheritDoc
     */
    public function save(ObjectTypeDescriptorInterface $objectType, $objectToSave)
    {
        if (!$this->isSuitableFor($objectType)) {
            throw new RuntimeException("Incompatible loader for type {$objectType->getTypeCode()}");
        }

        $this->rmaRepository->save($objectToSave);
    }
}
